@@ -2,12 +2,18 @@ package Date::Holidays::SUPERED;
 
 use base 'Date::Holidays::Super';
 
+sub new {
+    my $class = shift;
+    my $self = bless {}, $class;
+    return $self;
+}
+
 sub holidays {
     return { 1224 => 'christmas' };
 }
 
 sub is_holiday {
-    my ($year, $month, $day) = @_;
+    my ($class, $year, $month, $day) = @_;
     
     my $key;
     my $calendar = { 1224 => 'christmas' };
